

	clear
	set more off
	capture set max_memory 500M /* for stata 12 */
	capture set mem 500M		

	cap log close



//	DEPENDENT VARIABLES
	//	First Layer: Define Employment
		use "$data\sec3_labor.dta", clear
		merge m:1 hhid using "$data/sec_cover.dta"

		gen employed = (s3q1==1 | s3q3==1 | s3q4==1 | s3q5==1 |  ((s3q7==1 | s3q8==1) & (s3q10!=3 & s3q10!=4)) | ((s3q11==1 | s3q12==1) & (s3q15!=3 & s3q15!=4)) | (s3q16==1 & (s3q21!=3 & s3q21!=4))) 
		*During the last four weeks,  [NAME] did something to find a paid job
		*During the last four weeks, [Name] tried to start a business
		gen unemployed = ((s3q22==1 | s3q23==1))

		gen not_in_workforce = (unemployed==0 & employed==0)

		gen in_ag_not_in_workforce = (s3q10 ==3 | s3q10==4 | s3q15 ==3 | s3q15==4 | s3q21 ==3 | s3q21==4) if not_in_workforce==1
		gen inactive_not_in_workforce = (in_ag_not_in_workforce==0) if not_in_workforce==1
				
				
		label var employed "Being employed"
		label var unemployed "Being unemployed"
		label var not_in_workforce "Not being in the workforce"
		label var in_ag_not_in_workforce "Not being in the workforce but involved in agricultural activities for hh use"
		label var in_ag_not_in_workforce "Not being in the workforce and being inactive"

		gen employ_cats1=1 if employed==1
		replace employ_cats1=2 if unemployed==1
		replace employ_cats1=3 if not_in_workforce==1
		tab employ_cats1
				
	//	Second Layer: Define categories of employment based on the main activity (mutually exclusive)

		//	Self employment
		*Main job is in own business or farming activity
		*In a business or farm operated by a household member
		gen hh_employment = (s3q35==1 | s3q35==2) 

		*Wage employment
		*Worked As an employee for someone else or as an apprentice, trainee, intern
		gen wage_employment = (s3q35==3 | s3q35==4)

		gen employ_cats2=1 if hh_employment==1
		replace employ_cats2=0 if wage_employment==1

		gen wage_emp=0 if hh_employment==1
		replace wage_emp=1 if wage_employment==1

				
		label var hh_employment "Working as self-employed or for someone else in the household"
		label var wage_employment "Working as an employee, trainee or intern for someone else"
		label var employ_cats1 "Employment categories- employed, unemployed, NILF"
		label var employ_cats2 "Employment type- same as hh_employment"
		label var wage_emp "Dummy variable for wage employment"

		keep if s3q0 == 1 // working on the sample of working age adults (>= 15yo)
		keep hhid indiv hhweight cluster employ_cats1 employ_cats2 employed unemployed not_in_workforce ///
			 in_ag_not_in_workforce inactive_not_in_workforce hh_employment wage_employment wage_emp

		save "$interm/Variables.dta", replace


// CONSTRUCTING EXPLANATORY VARIABLES 
	
	//	Basic Covariates 
		use "$data/sec1_roster.dta", clear

		*Gender
		tab s1q2
		gen male=1 if s1q2==1
		replace male=0 if s1q2==2

		*Age
		tab age
		gen age_sq= age*age

		*Marital status
		tab s1q6
		gen marital=1 if s1q6==1 | s1q6==2 | s1q6==3  //married or cosensual union
		replace marital=2 if s1q6== 4| s1q6==5 | s1q6==6    //seperated, widowed or divorced
		replace marital=3 if s1q6==7   // never married
		tab s1q6 marital 

		tab marital, gen (m)
		rename m1 married
		rename m2 special_single
		rename m3 nev_married

		*Relationship to head of household
		gen hhead=1 if s1q5==1
		replace hhead=0 if s1q5!=1
		tab s1q5 hhead

		*Male household head
		gen male_hd=1 if male==1 & hhead==1
		replace male_hd=0 if male==0 & hhead==1
		tab male_hd 
		bys hhid: egen male_head=max(male_hd)
		tab male_head

		*Spouse lives in hhold
		label li s1q7
		gen spouse=1 if s1q7==1
		replace spouse=0 if s1q7==2
		bys hhid: egen spouse_present=max(spouse)
		tab spouse_present
		replace spouse_present=0 if spouse_present==.

		*Regional controls
		tab region
		label li region
		gen ashanti=1 if region==6
		replace ashanti=0 if region!=6
		replace ashanti=. if region==.
		tab region ashanti

		gen northern=1 if region==12 | region==13
		replace northern =0 if region >=1 & region <=11
		replace northern=0 if region >=14 & region <=16
		replace northern=. if region==.
		tab region northern

		*Residence controls
		label li urbrur
		gen urban=1 if urbrur==1
		replace urban=0 if urbrur==2
		tab urban urbrur

		*Household size
		gen id= _n
		egen hhsize=count(id), by(hhid indiv)
		*edit hhid indiv id hhsize
		egen hh_size = total(hhsize), by (hhid)
		*edit hhid indiv hhsize hh_size
		tab hh_size

		*Religion
		gen muslim=0 if s1q10== 2 | s1q10==3 | s1q10==4 | s1q10==5
		replace muslim=1 if s1q10==6
		replace muslim=. if s1q10==1 | s1q10==7 | s1q10==96
		tab s1q10 muslim

		keep hhid indiv married special_single nev_married muslim hh_size age age_sq male male_head marital ashanti ///
			 northern spouse_present urban

		label var male "person is male"
		label var male_head "household head is male"
		label var marital "marital status"
		label var married "person is married"
		label var nev_married "person is never married"
		label var special_single "person is separated/divorced or widowed"
		label var spouse_present "spouse is present in the household"
		label var urban "person resides in urban area"
		label var hh_size "household size"
		label var muslim "person belongs to Muslim religion"
		label var ashanti "person resides in Ashanti region"
		label var northern "person resides in Northern region"

		merge 1:1 hhid indiv using "$interm/Variables.dta"
		drop _merge
		save "$interm/Variables.dta", replace

		*Educational qualification or literacy (languages/calculations; more obs on literacy)
		use "$data/sec2_education.dta", clear
		*Completed grades
		tab s2q3, miss
		label li s2q3
		gen education= 1 if s2q3==0 | s2q3==1    // none or pre-school
		replace education= 1 if s2q3==.        // code missing values as "no schooling"
		replace education= 2 if s2q3>=11 & s2q3<=16   // primary school
		replace education= 3 if s2q3>=17 & s2q3<=23    // middle school
		replace education= 3 if s2q3>=24 & s2q3<=34   // secondary school
		replace education= 4 if s2q3>=41 & s2q3<=46    // tertiary

		replace education=. if s2q3==96
		tab s2q3 education
		tab education, miss

		gen sec_plus=1 if education>=3
		replace sec_plus=0 if education<3
		tab education sec_plus

		*Apprenticeship (current/past)
		label li s2q15
		gen apprentice= 1 if s2q15 ==1 | s2q15==2
		replace apprentice=0 if s2q15==3
		tab s2q15 apprentice

		keep hhid indiv education apprentice sec_plus
		label var education "highest educational level completed"
		label var apprentice "is an apprentice now or has been in the past"
		label var sec_plus "at least secondary school education completed"

		merge 1:1 hhid indiv using "$interm/Variables.dta"
		drop _merge
		save "$interm/Variables", replace

	//	Gender roles and attitudes 
		use "$data/sec7_gender.dta", clear
		*Only men should work outside the home 
		gen men_work= 1 if s7q3==4| s7q3==5
		replace men_work=0 if s7q3==1 | s7q3==2 | s7q3==3
		replace men_work=. if s7q3==.
		tab s7q3 men_work
		label var men_work "agree/strongly disagree that only men should work outside the house"

		*Ok for women to work outside home even if has young child
		gen women_work=1 if s7q4==1 | s7q4==2
		replace women_work=0 if s7q4==3 | s7q4==4 | s7q4==5
		replace women_work=. if s7q4==.
		tab s7q4 women_work
		label var women_work "disagree/strongly disagree that women should work outside the house"

		* Men should perform chores
		gen men_chores=1 if s7q5==1 | s7q5==2
		replace men_chores=0 if s7q5==3 | s7q5==4 | s7q5==5
		replace men_chores=. if s7q5==.
		tab s7q5 men_chores
		label var men_chores "disagree/ strongly disagree that Men should perform chores"

		*Women should perform chores
		gen women_chores=1 if s7q6==4 | s7q6==5
		replace women_chores=0 if s7q6==1 | s7q6==2 | s7q6==3
		replace women_chores=. if s7q6==.
		tab s7q6 women_chores
		label var women_chores "agree/ strongly agree that women should perform chores"

		*Men should care for children or dependents
		gen men_care=1 if s7q7==1 | s7q7==2
		replace men_care=0 if s7q7==3 | s7q7==4 | s7q7==5
		replace men_care=. if s7q7==.
		tab s7q7 men_care
		label var men_care "disagree/ strongly disagree that men should care for children or dependents"

		*Women should care for children or dependents
		gen women_care=1 if s7q8==4 | s7q8==5
		replace women_care=0 if s7q8==1 | s7q8==2 | s7q8==3
		replace women_care=. if s7q8==.
		tab s7q8 women_care
		label var women_care "agree/ strongly agree that women should care for children or dependents"

		*Women are as capable as men to manage workers
		gen women_capable= 1 if s7q9==1 | s7q9==2
		replace women_capable=0 if s7q9==3 | s7q9==4 | s7q9==5
		replace women_capable=. if s7q9==.
		tab s7q9 women_capable
		label var women_capable "disagree/ strongly disagree that women are as capable as men to manage workers"

		*Women are capable intellectually as men as being successful
		gen women_smart=1 if s7q10==1 | s7q10==2
		replace women_smart=0 if s7q10==3 | s7q10==4 | s7q10==5
		replace women_smart=. if s7q10==.
		tab s7q10 women_smart
		label var women_smart "disagree/ strongly disagree that women are capable intellectually as men as being successful"

		*Men should make all decisions
		gen men_decide=1 if s7q11==4 | s7q11==5
		replace men_decide=0 if s7q11==1 | s7q11==2 | s7q11==3
		replace men_decide=. if s7q11==.
		tab s7q11 men_decide
		label var men_decide "agree/ strongly agree that women are capable intellectually as men as being successful"

		*Women farmers should grow food
		gen women_food= 1 if s7q12== 4 | s7q12==5
		replace women_food=0 if s7q12==1 | s7q12==2 | s7q12==3
		replace women_food=. if s7q12==.
		tab s7q12 women_food
		label var women_food "agree/ strongly agree that Women farmers should grow food only"

		*Women grow food for market
		gen women_sale=1 if s7q13==1 | s7q13==2
		replace women_sale=0 if s7q13==3 | s7q13==4 | s7q13==5
		replace women_sale=. if s7q13==.
		tab s7q13 women_sale
		label var women_sale "disagree/ strongly disagree that Women farmers should grow food only"

		*Only men should grow crops for sale in the market
		gen men_sale=1 if s7q14==4 | s7q14==5
		replace men_sale=0 if s7q14==1 | s7q14==2 | s7q14==3
		replace men_sale=. if s7q14==.
		tab s7q14 men_sale
		label var men_sale "agree/ strongly agree that Women farmers should grow food only"

		*Ok for women to manage men working on land
		gen women_managers=1 if s7q15==1 | s7q15==2
		replace women_managers=0 if s7q15==3 | s7q15==4 | s7q15==5
		replace women_managers=. if s7q15==.
		tab s7q15 women_managers
		label var women_managers "disagree/ strongly disagree that Ok for women to manage men working on land"

		*Ok for men to maange women
		gen men_managers=1 if s7q16==4 | s7q16==5
		replace men_managers=0 if s7q16==1 | s7q16==2 | s7q16==3
		replace men_managers=. if s7q16==.
		tab s7q16 men_managers
		label var men_managers "agree/ strongly agree that Ok for men to maange women"

		*Index for Gender norms and attitudes
		zindex men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide women_food women_sale men_sale women_managers men_managers, gen(index_gendernorms)

		*Standardise index to range from 0 to 100
		foreach v of varlist index_gendernorms {
			summ `v', meanonly
			gen `v'_100 = 100*(`v'-`r(min)')/(`r(max)'-`r(min)')
		}
		su index_gendernorms index_gendernorms_100
		label var index_gendernorms "Index of gender norms"
		label var index_gendernorms_100 "Standardized 0-100 index of gender norms"

		keep hhid ea_code indiv men_work women_work men_chores women_chores men_care women_care women_capable ///
			 women_smart men_decide women_food women_sale men_sale women_managers men_managers index_gendernorms ///
			 index_gendernorms_100

		merge 1:1 hhid indiv using "$interm/Variables.dta"
		drop _merge
		save "$interm/Variables.dta", replace

		*Constructing EA Gender norms and attitudes (Endogeneity concern/ robustness check)
		use "$interm/Variables.dta"
		collapse index_gendernorms_100, by (ea_code)
		rename index_gendernorms_100 ea_gnorms

		merge 1:m ea_code using "$interm/Variables.dta"
		drop _merge
		replace ea_gnorms=. if index_gendernorms_100==.
		save "$interm/Variables.dta", replace

	//	Constructing Household wealth quintiles
		use "$data/sec9_assets.dta", clear
		*rename assets so code below runs smoothly
		rename s9q1__307 s9q1__305
		rename s9q1__308 s9q1__306
		rename s9q1__310 s9q1__307
		rename s9q1__311 s9q1__308
		rename s9q1__316 s9q1__309
		rename s9q1__317 s9q1__310
		rename s9q1__322 s9q1__311
		rename s9q1__324 s9q1__312
		rename s9q1__326 s9q1__313
		rename s9q1__327 s9q1__314
		rename s9q1__328 s9q1__315
		rename s9q1__329 s9q1__316
		rename s9q1__335 s9q1__317
		rename s9q1__336 s9q1__318
		rename s9q1__338 s9q1__319
		rename s9q1__340 s9q1__320
		rename s9q1__344 s9q1__321
		rename s9q1__346 s9q1__322
		rename s9q1__347 s9q1__323
		rename s9q1__348 s9q1__324
		rename s9q1__352 s9q1__325
		rename s9q1__353 s9q1__326


		forvalues A= 301/326 {
		  gen asset__`A'=0
		  replace asset__`A'=1 if s9q1__`A'>0 & s9q1__`A'~=.
		}

		*Generate PCA with assets
		pca asset_* 
		   predict pca_durables, score
		   lab var pca_durables "Durable Assets (PCA)"
		   sum pca_durables
		xtile WInd = pca_durables, nq(5)

		// Definition and labels of the quintiles
		label define class 1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5" 
		label val WInd class
		label var WInd  "Wealth class" 

		tab WInd, gen (Q)
		rename Q1 poorest
		rename Q2 poorer
		rename Q3 middle
		rename Q4 richer
		rename Q5 richest

		label var poorest "poorest wealth quintile"
		label var poorer "poorer wealth quintile"
		label var middle "middle wealth quintile"
		label var richer "richer wealth quintile"
		label var richest "richest wealth quintile"
		label var pca_durables "wealth scores"

		*Categorize 5 poverty quintiles into two classes- poor and non-poor
		gen poor=1 if poorest==1 | poorer==1
		replace poor=0 if middle==1 | richer==1 | richest==1
		label var poor  "person belongs to a poor household (i.e., bottom 2 wealth quintiles)" 

		keep hhid pca_durables WInd poorest poorer middle richer richest poor
		merge 1:m hhid using "$interm/Variables.dta"
		drop _merge
		save "$interm/Variables.dta", replace

	//	Personality traits 
		use "$data/sec8_personality.dta", clear
		*Construction from Laajaj, Rachid and Karen Macours. 2017

			*** Calculate naive scores (without acquiescence bias correction)
			* reverse code s8q1 and s8q3
			replace s8q1=. if s8q1>5
			replace s8q2=. if s8q2>5
			replace s8q3=. if s8q3>5
			recode s8q1 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q3 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen impulsive1 = rowmean(s8q1 s8q2 s8q3)
			label variable impulsive1 "Personality trait - impulsiveness (naive)"
			tab impulsive1		

			replace s8q4=. if s8q4>5
			replace s8q21=. if s8q21>5
			egen wk_central1 = rowmean(s8q4 s8q21)
			label variable wk_central1 "Personality trait - work centrality (naive)"
			tab wk_central1

			replace s8q5=. if s8q5>5
			replace s8q6=. if s8q6>5
			egen tenacity1 = rowmean(s8q5 s8q6)
			label variable tenacity1 "Personality trait - tenacity (naive)"
			tab tenacity1

			* reverse code s8q8 and s8q9
			replace s8q7=. if s8q7>5
			replace s8q8=. if s8q8>5
			replace s8q9=. if s8q9>5
			recode s8q8 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q9 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen polychronic1 = rowmean(s8q7 s8q8 s8q9)
			label variable polychronic1 "Personality trait - polychronicity (naive)"
			tab polychronic1
			
			* reverse code s8q12
			replace s8q10=. if s8q10>5
			replace s8q11=. if s8q11>5
			replace s8q12=. if s8q12>5
			recode s8q10 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q11 (1=5) (2=4) (3=3) (4=2) (5=1)
			
			egen locctl1 = rowmean(s8q10 s8q11 s8q12)
			label variable locctl1 "Personality trait - locus of control (naive)"
			tab locctl1
			
			replace s8q13=. if s8q13>5
			replace s8q14=. if s8q14>5
			replace s8q15=. if s8q15>5
			replace s8q16=. if s8q16>5
			replace s8q17=. if s8q17>5
			egen achievemt1 = rowmean(s8q13 s8q14 s8q15 s8q16 s8q17)
			label variable achievemt1 "Personality trait - achievement (naive)"
			tab achievemt1

			replace s8q18=. if s8q18>5
			replace s8q19=. if s8q19>5
			replace s8q20=. if s8q20>5
			egen pow_mot1 = rowmean(s8q18 s8q19 s8q20)
			label variable pow_mot1 "Personality trait - power motivation (naive)"
			tab pow_mot1

			replace s8q22=. if s8q22>5
			generate organized1 = s8q22
			label variable organized1 "Personality trait - organized person (naive)"
			tab organized1

			replace s8q23=. if s8q23>5
			replace s8q24=. if s8q24>5
			replace s8q25=. if s8q25>5
			replace s8q26=. if s8q26>5
			replace s8q27=. if s8q27>5
			replace s8q28=. if s8q28>5
			
			* reverse code s8q24 s8q26 and s8q27
			recode s8q24 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q26 (1=5) (2=4) (3=3) (4=2) (5=1)
			recode s8q27 (1=5) (2=4) (3=3) (4=2) (5=1)
			egen optimism1 = rowmean(s8q23 s8q24 s8q25 s8q26 s8q27 s8q28)
			label variable optimism1 "Personality trait - optimism (naive)"
			tab optimism1
			
		keep hhid indiv impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 organized1 optimism1  

		merge 1:1 hhid indiv using "$interm/Variables.dta"
		drop _merge
		save "$interm/Variables.dta", replace
		

	//	Additional Personality Traits Variables
		use "$data/sec8_personality.dta", clear
		*Plan tasks carefully
		tab s8q1
		gen plan=1 if s8q1==4 | s8q1==5
		replace plan=0 if s8q1==1 | s8q1==2 | s8q1==3
		replace plan=. if s8q1==.
		tab s8q1 plan
		label variable plan "agree/ strongly agree that plan tasks carefully"

		*Decisive
		tab s8q2
		gen decisive=1 if s8q2==4 | s8q2==5
		replace decisive=0 if s8q2==1 | s8q2==2 | s8q2==3
		replace decisive=. if s8q2==.
		tab s8q2 decisive
		label variable decisive "agree/ strongly agree that make up my mind quickly"

		*Save regularly
		gen save=1 if s8q3==4 | s8q3==5
		replace save=0 if s8q3==1 | s8q3==2 | s8q3==3
		replace save=. if s8q3==.
		tab s8q3 save
		label variable save "agree/ strongly agree that save regularly"

		*Passion for work
		gen passion=1 if s8q4==4 | s8q4==5
		replace passion=0 if s8q4==1 | s8q4==2 | s8q4==3
		replace passion=. if s8q4==.
		tab s8q4 passion
		label variable passion "agree/ strongly agree that look forward to returning to work"

		* Persistence when others quit
		gen persist= 1 if s8q5==4 | s8q5==5
		replace persist= 0 if s8q5==1 | s8q5==2 | s8q5==3
		replace persist=. if s8q5==. | s8q5==6
		tab s8q5 persist
		label variable persist "agree/ strongly agree that persisted when others quit"

		*Hard work even when others oppose
		gen hardwork=1 if s8q6==4 | s8q6==5
		replace hardwork=0 if s8q6==1 | s8q6==2 | s8q6==3
		replace hardwork=. if s8q6==.
		tab s8q6 hardwork
		label variable hardwork "agree/ strongly agree that continue to work in midst of opposition"

		*multitasking abilities
		gen multitask=1 if s8q7==4 | s8q7==5
		replace multitask=0 if s8q7==1 | s8q7==2 | s8q7==3
		replace multitask=. if s8q7==.
		tab s8q7 multitask
		label variable multitask "agree/ strongly agree that like to juggle several activities"

		*Complete tasks
		gen complete=1 if s8q8==4 | s8q8==5
		replace complete=0 if s8q8==1 | s8q8==2 | s8q8==3
		replace complete=. if s8q8==.
		tab s8q8 complete
		label variable complete "agree/ strongly agree that prefer to complete tasks"

		*Complete tasks from beginning to end
		gen tasks= 1 if s8q9==4 | s8q9==5
		replace tasks= 0 if s8q9==1 | s8q9==2 | s8q9==3
		replace tasks=. if s8q9==.
		tab s8q9 tasks
		label variable tasks "agree/ strongly agree that complete task before more to another"

		*Uncertainty about friends
		gen friends=1 if s8q10==1 | s8q10==2
		replace friends=0 if s8q10==3 | s8q10==4 | s8q10==5
		replace friends=. if s8q10==.
		tab s8q10 friends
		label variable friends "disagree/ strongly disagree that difficult to know who real friends are"

		*Afraid to try to new things
		gen fearless=1 if s8q11==1 | s8q11==2
		replace fearless=0 if s8q11==3 | s8q11==4 | s8q11==5
		replace fearless=. if s8q11==. 
		tab s8q11 fearless
		label variable fearless "disagree/ strongly disagree that never try anything unsure of"

		*Love for Risk-taking 
		gen riskloving=1 if s8q12==4 | s8q12==5
		replace riskloving=0 if s8q12==1 | s8q12==2 | s8q12==3
		replace riskloving=. if s8q12==.
		tab s8q12 riskloving
		label variable riskloving "agree/ strongly agree that person can get rich by taking risks"

		*Perform all tasks well
		gen perform=1 if s8q13==4 | s8q13==5
		replace perform=0 if s8q13==1 | s8q13==2 | s8q13==3
		replace perform=. if s8q13==.
		tab s8q13 perform
		label variable perform "agree/ strongly agree that perform tasks as well as possible"

		*Improving past performance
		gen past_perform=1 if s8q14==4 | s8q14==5
		replace past_perform=0 if s8q14==1 | s8q14==2 | s8q14==3
		replace past_perform=. if s8q14==.
		tab s8q14 past_perform
		label variable past_perform "agree/ strongly agree that important to improve past performance"

		*Group leadership
		gen leader=1 if s8q15==4 | s8q15==5
		replace leader=0 if s8q15==1 | s8q15==2 | s8q15==3
		replace leader=. if s8q15==.
		tab s8q15 leader
		label variable leader "agree/ strongly agree that prefer to direct group activities"

		*Competitive
		gen competitive=1 if s8q16==4 | s8q16==5
		replace competitive=0 if s8q16==1 | s8q16==2 | s8q16==3
		replace competitive=. if s8q16==.
		tab s8q16 competitive
		label variable competitive "agree/ strongly agree that try harder with competition"

		*Outperform others
		gen outperform=1 if s8q17==4 | s8q17==5
		replace outperform=0 if s8q17==1 | s8q17==2 | s8q17==3
		replace s8q17=. if s8q17==.
		tab s8q17 outperform
		label variable outperform "agree/ strongly agree that like to outperform others"

		*Planner
		tab s8q18
		gen planner=1 if s8q18==4 | s8q18==5
		replace planner=0 if s8q18==1 | s8q18==2 | s8q18==3
		replace planner=. if s8q18==.
		tab s8q18 planner
		label variable planner "agree/ strongly agree that enjoy deciding what people do"

		*Influencer
		gen influencer=1 if s8q19==4 | s8q19==5
		replace influencer=0 if s8q19==1 | s8q19==2 | s8q19==3
		replace influencer=. if s8q19==.
		tab s8q19 influencer
		label variable influencer "agree/ strongly agree that like having influence over people"

		*Control of events around
		gen control=1 if s8q20== 4| s8q20==5
		replace control=0 if s8q20==1 | s8q20==2 | s8q20==3
		replace control=. if s8q20==.
		tab s8q20 control
		label variable control "agree/ strongly agree that like to have control over events around me"

		*Workaholic (The most important thing that happens in life involves work)
		gen workaholic=1 if s8q21== 4 | s8q21==5
		replace workaholic=0 if s8q21==1 | s8q21==2 | s8q21==3
		replace workaholic=. if s8q21==.
		tab s8q21 workaholic
		label variable workaholic "agree/ strongly agree that all important things involve work"

		*Organized
		gen organised=1 if s8q22==4 | s8q22==5
		replace organised=0 if s8q22==1 | s8q22==2 | s8q22==3
		replace organised=. if s8q22==.
		tab s8q22 organised
		label variable organised "agree/ strongly agree that I am very organised"

		*Hopeful (?)
		gen hopeful=1 if s8q23==4 | s8q23==5
		replace hopeful=0 if s8q23==1 | s8q23==2 | s8q23==3
		replace hopeful=. if s8q23==.
		tab s8q23 hopeful
		label variable hopeful "agree/ strongly agree that expect the best in uncertain times"

		*Unbeliever 
		gen believe=1 if s8q24==1 | s8q24==2
		replace believe=0 if s8q24==3 | s8q24==4 | s8q24==5
		replace believe=. if s8q24==.
		tab s8q24 believe
		label variable believe "disagree/ strongly disagree that if something can go wrong it will"

		*Optimistic
		gen optimistic=1 if s8q25==4 | s8q25==5
		replace optimistic=0 if s8q25==1 | s8q25==2 | s8q25==3
		replace optimistic=. if s8q25==.
		tab s8q25 optimistic
		label variable optimistic "agree/ strongly agree that always optimistic about future"

		*Pessimistic
		gen pessimistic=1 if s8q26==1 | s8q26==2 | s8q26==3
		replace pessimistic=0 if s8q26==4 | s8q26==5
		replace pessimistic=. if s8q26==.
		tab s8q26 pessimistic
		label variable pessimistic "disagree/ strongly disagree that things never expected to go my way"

		* Good things do happen to me
		gen badluck=1 if s8q27==1 | s8q27==2 | s8q27==3
		replace badluck=0 if s8q27==4 | s8q27==5
		replace badluck=. if s8q27==.
		tab s8q27 badluck
		label variable badluck "disagree/ strongly disagree that good things never happen to me"

		*Overall blessed
		gen blessed= 1 if s8q28==4 | s8q28==5
		replace blessed=0 if s8q28==1 | s8q28==2 | s8q28==3
		replace blessed=. if s8q28==.
		tab s8q28 blessed

		label variable blessed "agree/ strongly agree that more good things happen to me than bad"

		keep hhid indiv hhid indiv plan decisive save passion persist hardwork multitask complete tasks friends fearless ///
			 riskloving perform past_perform leader competitive outperform planner influencer control workaholic organised ///
			 hopeful believe optimistic pessimistic badluck blessed

	//	Save Final Analytical Datafile
		merge 1:1 hhid indiv using "$interm/Variables.dta"
		
		save "$interm/Variables.dta", replace
