**************************************************************************************************
*****	Gender Norms and Personality Traits on Employment Outcome in Ghana - WB PRWP Series	******
********************	Before Running this Dofile, please ensure all the ************************
********************		Data Preparatory Dofiles have be Implemented  ************************

****************************************** TABLES ************************************************

	//	Set up System
		set more off
		capture set max_memory 500M /* for stata 12 */
		capture set mem 500M		
		cap log close
		clear all

	//	Call the Final Analytical Datafile
		use "$interm/Variables.dta", clear

		
	//	Figure 1. Differences in Personality Traits by Men and Women, Pooled Sample (weighted)
		estimates clear
		sort male
		by male: eststo: estpost summarize blessed tasks plan passion competitive complete organised optimistic past_perform ///
										   riskloving persist hardwork workaholic outperform hopeful perform control save pessimistic ///
										   decisive planner influencer badluck leader believe multitask fearless friends  [aw=hhweight]
				esttab using "$tables\Figure 1 - Differences in Personality Traits", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") label nodepvar 
		

		
	//	Table 2. Descriptive statistics of analytical variables (weighted)

		*Keep Only Sample needed for Regression Analysis 
		mlogit employ_cats1 index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 ///
			   organized1 optimism1 male age age_sq married sec_plus male_head muslim spouse_present hh_size poor urban ///
			   ashanti, vce(cluster cluster)  base(3)
			keep if e(sample)

		*Pooled 
		estimates clear
		eststo:  estpost summarize employed unemployed not_in_workforce hh_employment wage_employment male age married ///
				 sec_plus male_head muslim spouse_present hh_size poor urban ashanti [aweight= hhweight]
			esttab using "$tables\Table 2 - Pooled sample", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))")  nodepvar 

		*By Gender
		estimates clear
		sort male
		by male: eststo: quietly estpost summarize employed unemployed not_in_workforce hh_employment wage_employment male ///
				 age married sec_plus male_head muslim spouse_present hh_size poor urban ashanti [aweight= hhweight]
			esttab using "$tables\Table 2 - Women and Men sample", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))")  nodepvar 

		*T-tests
		estimates clear
		estpost ttest employed unemployed not_in_workforce hh_employment wage_employment male age married sec_plus ///
				male_head muslim spouse_present hh_size poor urban ashanti, by (male) 
			esttab using "$tables\Table 2 - t Tests", csv replace wide starlevels( * 0.10 ** 0.05 *** 0.010)


	//	Table 3. Differences in labor market outcomes by different subgroups (weighted)
			
			clear matrix	
			foreach var of varlist employed unemployed not_in_workforce hh_employment wage_employment {
				foreach m of varlist sec_plus male urban poor ashanti {
					sort `m' 
					sum `var' [aweight= hhweight] if `m' ==1
					matrix Q1 = r(mean)
					sum `var' [aweight= hhweight] if `m' ==0
					matrix Q2 = r(mean)
					*matrix rown Q1 = "`var'"
					mat M = Q1\Q2
					mat `var'`m' = nullmat(`var'`m'),(M)
					mat T3=nullmat(T3)\(`var'`m')	
					}
				}
				
					matlist T3
					mat A = T3[1..10,1..1]
					mat B = T3[11..20,1..1]		
					mat C = T3[21..30,1..1]		
					mat D = T3[31..40,1..1]		
					mat E = T3[41..50,1..1]	
					mat Table3 = A,B,C,D,E
					matlist Table3

			putexcel set "$tables\Table 3 - Differences in labor market outcomes by different subgroups", sheet("Table3") mod
			putexcel B2=matrix(Table3[1...,1...])		


	//	Table 4. Differences in perceptions of gender roles by men and women (weighted)
		estimates clear
		sort male
		by male: eststo: quietly estpost summarize men_work women_work men_chores women_chores men_care women_care ///
			women_capable women_smart men_decide women_food women_sale men_sale women_managers men_managers [aweight= hhweight]
		esttab using "$tables\Table 4a - Top - Women Men", csv replace cells("mean(fmt(3) label(Mean)) sd(fmt(2) label(SD))") label nodepvar 

		* Codes below generate the values in parentheses beneath each of the results from the above syntax
			clear matrix	
			foreach var of varlist men_work women_work men_chores women_chores men_care women_care women_capable women_smart ///
								   men_decide women_food women_sale men_sale women_managers men_manager {
				foreach m of varlist male {
					sum index_gendernorms_100 [aweight= hhweight] if `var' == 1 & `m' == 0
						matrix Q1 = r(mean)
					sum index_gendernorms_100 [aweight= hhweight] if `var' == 1 & `m' == 1
						matrix Q2 = r(mean)
							mat M = Q1,Q2
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat T4=nullmat(T4)\(`var'`m')	
					}
						sum index_gendernorms_100 [aweight= hhweight] if male == 0
							matrix Q3 = r(mean)
						sum index_gendernorms_100 [aweight= hhweight] if male == 1
							matrix Q4 = r(mean)
								mat N = Q3,Q4					
					}

					mat Table4b = T4\N
				matlist Table4b
				
			putexcel set "$tables\Table 4b - Differences in perceptions of gender roles by men and women", sheet("Table4b") mod
			putexcel B2=matrix(Table4b[1...,1...])					

			*Column 5- ttest of differences
			estimates clear  
			estpost ttest men_work women_work men_chores women_chores men_care women_care women_capable women_smart men_decide ///
					women_food women_sale men_sale women_managers men_managers index_gendernorms_100, by (male)
				esttab using "$tables\Table 4c - Difference Test", csv  replace  wide label starlevels( * 0.10 ** 0.05 *** 0.010)
				

	//	Table 5 Distribution of gender norm index and personality groups, by men and women (weighted)
		*Pooled 
		estimates clear
		eststo: quietly estpost summarize index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 ///
				pow_mot1 organized1 optimism1  [aweight= hhweight]
			esttab using "$tables\Table 5 - Pooled sample", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		*By male/ Female samples
		estimates clear
		sort male
		by male: eststo: quietly estpost summarize index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 ///
				achievemt1 pow_mot1 organized1 optimism1  [aweight= hhweight]
			esttab using "$tables\Table 5 - Women and Men", csv  replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		*T-tests
		estimates clear
		estpost ttest index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 organized1 ///
				optimism1 , by (male) 
			esttab using "$tables\Table 5 - t Test", csv replace wide starlevels( * 0.10 ** 0.05 *** 0.010)


	// REGRESSION - MNL and LPM
		use "$interm/Variables.dta", clear
		
	//	Globals for Control Variables
		global xvars male age age_sq married sec_plus male_head muslim spouse_present hh_size poor urban ashanti
		global p_traits impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 organized1 optimism1
					 
	//	Table 6. MNL of employment outcomes, without gender role attitudes and personality traits
		estimates clear
		mlogit employ_cats1 $xvars, vce(cluster cluster)  base(3)
			estimates store m1

		mlogit employ_cats1 $xvars if male==0, vce(cluster cluster)  base(3)
			estimates store m2

		mlogit employ_cats1 $xvars if male==1, vce(cluster cluster)  base(3)
			estimates store m3 
		
		outreg2 [m1 m2 m3] using "$tables/Table 6 - MNL of employment outcomes.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) stats(coef tstat)
		

	//	Table 7 LPM of Wage Employment, without Gender role attitudes and Personality traits
		estimates clear
		reg wage_emp $xvars, vce(cluster cluster)  
			estimates store m1

		reg wage_emp $xvars if male==0, vce(cluster cluster)  
			estimates store m2

		reg wage_emp $xvars if male==1, vce(cluster cluster)  
			estimates store m3
 
		outreg2 [m1 m2 m3] using "$tables/Table 7 - LPM of wage employment.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) stats(coef tstat)
 
		
	//	Table 8. MNL regressions - effects of gender role attitudes and personality traits on employment outcomes (pooled sample)
		mlogit employ_cats1 index_gendernorms_100 $p_traits $xvars, vce(cluster cluster) base(3)
		keep if e(sample)

		estimates clear

		mlogit employ_cats1 index_gendernorms_100 , vce(cluster cluster)  base(3)
			estimates store m1

		mlogit employ_cats1 index_gendernorms_100 $xvars, vce(cluster cluster)  base(3)

			estimates store m2

		mlogit employ_cats1 index_gendernorms_100 $p_traits $xvars, vce(cluster cluster)  base(3)
			estimates store m3

		*Impulsiveness
		mlogit employ_cats1 c.index_gendernorms_100##c.impulsive1 $xvars, vce(cluster cluster) base(3) 
		estimates store m4

		*Work centrality
		mlogit employ_cats1 c.index_gendernorms_100##c.wk_central1 $xvars, vce(cluster cluster) base(3) 
		estimates store m5

		*Tenacity
		mlogit employ_cats1 c.index_gendernorms_100##c.tenacity1 $xvars, vce(cluster cluster) base(3) 
		estimates store m6

		*Polychronicity
		mlogit employ_cats1  c.index_gendernorms_100##c.polychronic1 $xvars, vce(cluster cluster) base(3) 
		estimates store m7

		*Locus of control
		mlogit employ_cats1  c.index_gendernorms_100##c.locctl1 $xvars, vce(cluster cluster) base(3) 
		estimates store m8

		*Achievement
		mlogit employ_cats1  c.index_gendernorms_100##c.achievemt1 $xvars, vce(cluster cluster) base(3) 
		estimates store m9

		*Power motivation
		mlogit employ_cats1  c.index_gendernorms_100##c.pow_mot1 $xvars, vce(cluster cluster) base(3) 
		estimates store m10

		*Organized
		mlogit employ_cats1  c.index_gendernorms_100##c.organized1 $xvars, vce(cluster cluster) base(3) 
		estimates store m11

		*Optimism
		mlogit employ_cats1  c.index_gendernorms_100##c.optimism1 $xvars, vce(cluster cluster) base(3) 
		estimates store m12

		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 8 - MNL PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) stats(coef tstat)


	//	Table 9. MNL regressions- effects of gender role attitudes and personality traits on employment outcomes (women sample)
		estimates clear
		mlogit employ_cats1 index_gendernorms_100 if male==0, vce(cluster cluster)  base(3)
			estimates store m1

		mlogit employ_cats1 index_gendernorms_100 $xvars if male==0, vce(cluster cluster)  base(3)
			estimates store m2

		mlogit employ_cats1 index_gendernorms_100 $p_traits $xvars if male==0, vce(cluster cluster)  base(3)
			estimates store m3

		*Impulsive
		mlogit employ_cats1 c.index_gendernorms_100##c.impulsive1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m4

		*Work centrality
		mlogit employ_cats1 c.index_gendernorms_100##c.wk_central1  $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m5

		*Tenacity
		mlogit employ_cats1  c.index_gendernorms_100##c.tenacity1  $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m6

		*Polychronicity
		mlogit employ_cats1 c.index_gendernorms_100##c.polychronic1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m7

		*Locus of control
		mlogit employ_cats1 c.index_gendernorms_100##c.locctl1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m8

		*Achievement
		mlogit employ_cats1 c.index_gendernorms_100##c.achievemt1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m9

		*Power Motivation
		mlogit employ_cats1  c.index_gendernorms_100##c.pow_mot1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m10

		*Organised
		mlogit employ_cats1  c.index_gendernorms_100##c.organized1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m11

		*Optimism
		mlogit employ_cats1  c.index_gendernorms_100##c.optimism1 $xvars if male==0, vce(cluster cluster) base(3) 
			estimates store m12
		
		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 9 - Women MNL PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) drop(0.*) stats(coef tstat)


	//	Table 10. MNL regressions- effects of gender role attitudes and personality traits on employment outcomes (men sample)
		estimates clear
		mlogit employ_cats1 index_gendernorms_100 if male==1, vce(cluster cluster)  base(3)
			estimates store m1

		mlogit employ_cats1 index_gendernorms_100 $xvars if male==1, vce(cluster cluster)  base(3)
			estimates store m2

		mlogit employ_cats1 index_gendernorms_100 $p_traits $xvars if male==1, vce(cluster cluster)  base(3)
			estimates store m3

		*Impulsive
		mlogit employ_cats1 c.index_gendernorms_100##c.impulsive1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m4

		*Work Central
		mlogit employ_cats1 c.index_gendernorms_100##c.wk_central1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m5

		*Tenacity
		mlogit employ_cats1  c.index_gendernorms_100##c.tenacity1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m6

		*Polychronicity
		mlogit employ_cats1 c.index_gendernorms_100##c.polychronic1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m7

		*Locus of control
		mlogit employ_cats1 c.index_gendernorms_100##c.locctl1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m8

		*Achievement
		mlogit employ_cats1 c.index_gendernorms_100##c.achievemt1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m9

		*Power Motivation
		mlogit employ_cats1 c.index_gendernorms_100##c.pow_mot1  $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m10

		*Organized
		mlogit employ_cats1  c.index_gendernorms_100##c.organized1  $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m11

		*Optimism
		mlogit employ_cats1  c.index_gendernorms_100##c.optimism1 $xvars if male==1, vce(cluster cluster) base(3) 
			estimates store m12

		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 10 - Men MNL PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) drop(0.*) stats(coef tstat)


	//	Table 11. LPM regressions- effects of norms and personality traits on wage employment  (vs. self-employment) - pooled sample
		estimates clear
		reg wage_emp index_gendernorms_100, vce(cluster cluster) 
			estimates store m1

		reg wage_emp index_gendernorms_100 $xvars, vce(cluster cluster)  
			estimates store m2

		reg wage_emp index_gendernorms_100 $p_traits $xvars, vce(cluster cluster)  
			estimates store m3

		*Impulsiveness
		reg wage_emp c.index_gendernorms_100##c.impulsive1 $xvars, vce(cluster cluster) 
			estimates store m4

		*Work central
		reg wage_emp c.index_gendernorms_100##c.wk_central1 $xvars, vce(cluster cluster) 
			estimates store m5

		*Tenacity
		reg wage_emp c.index_gendernorms_100##c.tenacity1 $xvars, vce(cluster cluster) 
			estimates store m6

		*Polychronicity
		reg wage_emp c.index_gendernorms_100##c.polychronic1 $xvars, vce(cluster cluster) 
			estimates store m7

		*Locus of control
		reg wage_emp c.index_gendernorms_100##c.locctl1 $xvars, vce(cluster cluster) 
			estimates store m8

		*Achievement
		reg wage_emp c.index_gendernorms_100##c.achievemt1 $xvars, vce(cluster cluster) 
			estimates store m9

		*Power motivation
		reg wage_emp c.index_gendernorms_100##c.pow_mot1 $xvars, vce(cluster cluster) 
			estimates store m10

		*Organized
		reg wage_emp  c.index_gendernorms_100##c.organized1 $xvars, vce(cluster cluster) 
			estimates store m11

		*Optimism
		reg wage_emp c.index_gendernorms_100##c.optimism1 $xvars, vce(cluster cluster) 
			estimates store m12 

		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 11 - LPM Wage PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) drop(0.*)  stats(coef tstat)

		
	//	Table 12. LPM regressions- effects of norms and personality traits on wage employment  (vs. self-employment)- women sample
		estimates clear
		reg wage_emp index_gendernorms_100 if male==0, vce(cluster cluster)  
		estimates store m1

		reg wage_emp index_gendernorms_100  $xvars if male==0, vce(cluster cluster)  
		estimates store m2


		reg wage_emp index_gendernorms_100 $p_traits $xvars if male==0, vce(cluster cluster)  
		estimates store m3

		*Impulsive
		reg wage_emp c.index_gendernorms_100##c.impulsive1 $xvars if male==0, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg wage_emp c.index_gendernorms_100##c.wk_central1 $xvars if male==0, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg wage_emp  c.index_gendernorms_100##c.tenacity1 $xvars if male==0, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg wage_emp c.index_gendernorms_100##c.polychronic1 $xvars if male==0, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg wage_emp c.index_gendernorms_100##c.locctl1 $xvars if male==0, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg wage_emp  c.index_gendernorms_100##c.achievemt1 $xvars if male==0, vce(cluster cluster) 
		estimates store m9

		*Power motivation
		reg wage_emp  c.index_gendernorms_100##c.pow_mot1 $xvars if male==0, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg wage_emp c.index_gendernorms_100##c.organized1  $xvars if male==0, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg wage_emp c.index_gendernorms_100##c.optimism1 $xvars if male==0, vce(cluster cluster) 
		estimates store m12

		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 12 - Women LPM Wage PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) drop(0.*) stats(coef tstat)
		
		
		
	//	Table 13. LPM regressions- effects of norms and personality traits on wage employment  (vs. self-employment)- men sample
		estimates clear
		reg wage_emp index_gendernorms_100 if male==1, vce(cluster cluster)  
		estimates store m1

		reg wage_emp index_gendernorms_100 $xvars if male==1, vce(cluster cluster)  
		estimates store m2

		reg wage_emp index_gendernorms_100 $p_traits $xvars if male==1, vce(cluster cluster)  
		estimates store m3

		*Impulsive
		reg wage_emp c.index_gendernorms_100##c.impulsive1 $xvars if male==1, vce(cluster cluster) 
		estimates store m4

		*Work centrality
		reg wage_emp c.index_gendernorms_100##c.wk_central1 $xvars if male==1, vce(cluster cluster) 
		estimates store m5

		*Tenacity
		reg wage_emp c.index_gendernorms_100##c.tenacity1 $xvars if male==1, vce(cluster cluster) 
		estimates store m6

		*Polychronicity
		reg wage_emp  c.index_gendernorms_100##c.polychronic1 $xvars if male==1, vce(cluster cluster) 
		estimates store m7

		*Locus of control
		reg wage_emp c.index_gendernorms_100##c.locctl1 $xvars if male==1, vce(cluster cluster) 
		estimates store m8

		*Achievement
		reg wage_emp c.index_gendernorms_100##c.achievemt1 $xvars if male==1, vce(cluster cluster) 
		estimates store m9

		*Power Motivation
		reg wage_emp c.index_gendernorms_100##c.pow_mot1 $xvars if male==1, vce(cluster cluster) 
		estimates store m10

		*Organized
		reg wage_emp c.index_gendernorms_100##c.organized1 $xvars if male==1, vce(cluster cluster) 
		estimates store m11

		*Optimism
		reg wage_emp c.index_gendernorms_100##c.optimism1 $xvars if male==1, vce(cluster cluster) 
		estimates store m12

		outreg2 [m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12] using "$tables/Table 13 - Men LPM Wage PT and GRA.xls", replace symbol(***, **, *) e(N ll r2 F) dec(3) drop(0.*) stats(coef tstat)  
		
	
	
	//	Figure A1. Comparison of employment outcomes for full and analytic sample,  Ghana Informal Sector Measurement Study, by gender and region
		use "$interm/Variables.dta", replace
		estimates clear
			clear matrix	
			foreach var of varlist employed unemployed not_in_workforce hh_employment wage_employment {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & ashanti == 1
						matrix Q1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & ashanti == 0
						matrix Q2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & ashanti == 1
						matrix Q3 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & ashanti == 0
						matrix Q4 = r(mean)
						mat M = Q1, Q2, Q3, Q4
							mat `var'`m' = nullmat(`var'`m'),(M)
							mat TA1=nullmat(TA1)\(`var'`m')	
						}			
					}

				matlist TA1
			putexcel set "$tables\Figure A1 - Comparison of employment outcomes for full and analytic sample", sheet("FigureA1") mod
			putexcel B4=matrix(TA1[1...,1...])		
			
			
		*Second graph on "Analytic sample"
		estimates clear
		mlogit employ_cats1 index_gendernorms_100 impulsive1 wk_central1 tenacity1 polychronic1 locctl1 achievemt1 pow_mot1 ///
			   organized1 optimism1 male age age_sq married sec_plus male_head muslim spouse_present hh_size poor urban ///
			   ashanti, vce(cluster cluster)  base(3)
			keep if e(sample)

			clear matrix	
			foreach var of varlist employed unemployed not_in_workforce hh_employment wage_employment {
				foreach m of varlist male {
					sum `var' [aweight= hhweight] if `m' == 0 & ashanti == 1
						matrix P1 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 0 & ashanti == 0
						matrix P2 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & ashanti == 1
						matrix P3 = r(mean)
					sum `var' [aweight= hhweight] if `m' == 1 & ashanti == 0
						matrix P4 = r(mean)
						mat N = P1, P2, P3, P4
							mat `var'`m' = nullmat(`var'`m'),(N)
							mat TA2=nullmat(TA2)\(`var'`m')	
						}			
					}

				matlist TA2
			putexcel set "$tables\Figure A1 - Comparison of employment outcomes for full and analytic sample", sheet("FigureA1") mod
			putexcel B13=matrix(TA2[1...,1...])	
			


	//	Table A1. Descriptive statistics of full sample (weighted)
		***General summary stats (full sample)
		estimates clear
		eststo: quietly estpost summarize employed unemployed not_in_workforce hh_employment wage_employment male age married sec_plus male_head muslim spouse_present hh_size poor urban ashanti northern [aweight= hhweight]
			esttab using "$tables\Table A1 - Full sample", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		*By male/ Female samples
		estimates clear
		sort male
		by male: eststo: quietly estpost summarize employed unemployed not_in_workforce hh_employment wage_employment male age married sec_plus male_head muslim spouse_present hh_size poor urban ashanti northern [aweight= hhweight]
		esttab using "$tables\Table A1 - Women and Men", csv replace cells("mean(fmt(2) label(Mean)) sd(fmt(2) label(SD))") nodepvar 

		*T-tests
		estimates clear
		estpost ttest employed unemployed not_in_workforce hh_employment wage_employment male age married sec_plus male_head muslim spouse_present hh_size poor urban ashanti northern, by (male) 
		esttab using "$tables\Table A1 - t Test", csv  replace wide  starlevels( * 0.10 ** 0.05 *** 0.010)
		
		
****************************************************************END***************************************************************************